const amqp = require( 'amqplib/callback_api' );

module.exports = ({
  host = 'localhost',
  port = 5672,
  username = 'guest',
  password = 'guest',
  vhost = '/',
  exchange = 'dhis2',
  keys = []
}) => {
  const connectionString = `amqp://${username}:${password}@${host}:${port}${vhost}`;

  amqp.connect( connectionString, (err, conn) => {
    if ( err ) {
      console.error( err );
      process.exit( -1 );
    }

    conn.createChannel( (err, ch) => {
      if ( err ) {
        console.error( err );
        process.exit( -2 );
      }

      ch.assertExchange( exchange, 'topic', {durable: true} );

      ch.assertQueue( '', {exclusive: true}, (err, q) => {
        if ( err ) {
          console.error( err );
          process.exit( -3 );
        }

        console.log( ' [*] Waiting for messages. To exit press CTRL+C' );

        keys.forEach( key => ch.bindQueue( q.queue, 'dhis2', key ) );

        ch.consume( q.queue, msg => {
          console.log( " [x] %s:'%s'", msg.fields.routingKey, msg.content.toString() );
        }, {noAck: true} );
      } );
    } );
  } );
};