const amqp = require( './amqp' );

const collect = (val, memo) => {
  memo.push( val );
  return memo;
};

const defaults = {
  host: 'localhost',
  port: 5672,
  username: 'guest',
  password: 'guest',
  vhost: '/',
  exchange: 'dhis2'
};

module.exports = program => {
  const cmd = program.command( 'event' )
    .description( 'listen to DHIS2 events' )
    .option( '-H, --host [host]', `AMQP host to connect to (default: ${defaults.host})`, defaults.host )
    .option( '-p, --port [port]', `AMQP port to connect to (default: ${defaults.port})`, defaults.port )
    .option( '-u, --user [user]', `AMQP user:pass to connect to (default: ${defaults.username}:${defaults.password})`, `${defaults.username}:${defaults.password}` )
    .option( '-L, --virtual-host [vhost]', `AMQP virtual host to connect to (default: ${defaults.vhost})`, defaults.vhost )
    .option( '-e, --exchange [exchange]', `AMQP exchange to connect to (default: ${defaults.exchange})`, defaults.exchange )
    .option( '-k, --key <key>', 'AMQP topic key', collect, [] )
    .action( ({host, port, user, virtualHost, exchange, key}) => {
      if ( !key || key.length === 0 ) {
        console.error( 'ERR: at least one topic key is required, -h for more information.' );
        process.exit( 0 );
      }

      user = user.split( ':' );

      amqp( {host, port, username: user[0], password: user[1], vhost: virtualHost, exchange, keys: key} )
    } );

  cmd.on( '--help', function() {
    console.log( '' );
    console.log( '  Examples:' );
    console.log( '' );
    console.log( '    $ dhis2 event -k metadata.#' );
    console.log( '    $ dhis2 event -H 192.168.0.1 -p 5555 -u admin:district -k metadata.#' );
    console.log( '    $ dhis2 event -k #.JvsoIvr8x8u -k #.uICb2GPP4Ra' );
    console.log( '' );
  } );

  return cmd;
};
